@@ -23,9 +23,11 @@ from aliyunsdkgpdb.endpoint import endpoint_data
 class CheckServiceLinkedRoleRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'gpdb', '2016-05-03', 'CheckServiceLinkedRole','gpdb')
+		RpcRequest.__init__(self, 'gpdb', '2016-05-03', 'CheckServiceLinkedRole')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
