@@ -31,6 +31,11 @@ class DescribeDBInstanceNetInfoRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_ConnectionString(self): # String
+		return self.get_query_params().get('ConnectionString')
+
+	def set_ConnectionString(self, ConnectionString):  # String
+		self.add_query_param('ConnectionString', ConnectionString)
 	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
