@@ -23,88 +23,76 @@ from aliyunsdkgpdb.endpoint import endpoint_data
 class DescribeSQLLogCountRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'gpdb', '2016-05-03', 'DescribeSQLLogCount','gpdb')
+		RpcRequest.__init__(self, 'gpdb', '2016-05-03', 'DescribeSQLLogCount')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_StartTime(self):
+	def get_StartTime(self): # String
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_QueryKeywords(self):
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_QueryKeywords(self): # String
 		return self.get_query_params().get('QueryKeywords')
 
-	def set_QueryKeywords(self,QueryKeywords):
-		self.add_query_param('QueryKeywords',QueryKeywords)
-
-	def get_Database(self):
+	def set_QueryKeywords(self, QueryKeywords):  # String
+		self.add_query_param('QueryKeywords', QueryKeywords)
+	def get_Database(self): # String
 		return self.get_query_params().get('Database')
 
-	def set_Database(self,Database):
-		self.add_query_param('Database',Database)
-
-	def get_SourceIP(self):
+	def set_Database(self, Database):  # String
+		self.add_query_param('Database', Database)
+	def get_SourceIP(self): # String
 		return self.get_query_params().get('SourceIP')
 
-	def set_SourceIP(self,SourceIP):
-		self.add_query_param('SourceIP',SourceIP)
-
-	def get_MinExecuteCost(self):
+	def set_SourceIP(self, SourceIP):  # String
+		self.add_query_param('SourceIP', SourceIP)
+	def get_MinExecuteCost(self): # String
 		return self.get_query_params().get('MinExecuteCost')
 
-	def set_MinExecuteCost(self,MinExecuteCost):
-		self.add_query_param('MinExecuteCost',MinExecuteCost)
-
-	def get_DBInstanceId(self):
+	def set_MinExecuteCost(self, MinExecuteCost):  # String
+		self.add_query_param('MinExecuteCost', MinExecuteCost)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_MaxExecuteCost(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_MaxExecuteCost(self): # String
 		return self.get_query_params().get('MaxExecuteCost')
 
-	def set_MaxExecuteCost(self,MaxExecuteCost):
-		self.add_query_param('MaxExecuteCost',MaxExecuteCost)
-
-	def get_ExecuteCost(self):
+	def set_MaxExecuteCost(self, MaxExecuteCost):  # String
+		self.add_query_param('MaxExecuteCost', MaxExecuteCost)
+	def get_ExecuteCost(self): # String
 		return self.get_query_params().get('ExecuteCost')
 
-	def set_ExecuteCost(self,ExecuteCost):
-		self.add_query_param('ExecuteCost',ExecuteCost)
-
-	def get_ExecuteState(self):
+	def set_ExecuteCost(self, ExecuteCost):  # String
+		self.add_query_param('ExecuteCost', ExecuteCost)
+	def get_ExecuteState(self): # String
 		return self.get_query_params().get('ExecuteState')
 
-	def set_ExecuteState(self,ExecuteState):
-		self.add_query_param('ExecuteState',ExecuteState)
-
-	def get_EndTime(self):
+	def set_ExecuteState(self, ExecuteState):  # String
+		self.add_query_param('ExecuteState', ExecuteState)
+	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_OperationType(self):
+	def set_EndTime(self, EndTime):  # String
+		self.add_query_param('EndTime', EndTime)
+	def get_OperationType(self): # String
 		return self.get_query_params().get('OperationType')
 
-	def set_OperationType(self,OperationType):
-		self.add_query_param('OperationType',OperationType)
-
-	def get_OperationClass(self):
+	def set_OperationType(self, OperationType):  # String
+		self.add_query_param('OperationType', OperationType)
+	def get_OperationClass(self): # String
 		return self.get_query_params().get('OperationClass')
 
-	def set_OperationClass(self,OperationClass):
-		self.add_query_param('OperationClass',OperationClass)
-
-	def get_User(self):
+	def set_OperationClass(self, OperationClass):  # String
+		self.add_query_param('OperationClass', OperationClass)
+	def get_User(self): # String
 		return self.get_query_params().get('User')
 
-	def set_User(self,User):
-		self.add_query_param('User',User)
\ No newline at end of file
+	def set_User(self, User):  # String
+		self.add_query_param('User', User)
