@@ -23,34 +23,31 @@ from aliyunsdkgpdb.endpoint import endpoint_data
 class ModifyDBInstanceConnectionStringRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'gpdb', '2016-05-03', 'ModifyDBInstanceConnectionString','gpdb')
+		RpcRequest.__init__(self, 'gpdb', '2016-05-03', 'ModifyDBInstanceConnectionString')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ConnectionStringPrefix(self):
+	def get_ConnectionStringPrefix(self): # String
 		return self.get_query_params().get('ConnectionStringPrefix')
 
-	def set_ConnectionStringPrefix(self,ConnectionStringPrefix):
-		self.add_query_param('ConnectionStringPrefix',ConnectionStringPrefix)
-
-	def get_DBInstanceId(self):
+	def set_ConnectionStringPrefix(self, ConnectionStringPrefix):  # String
+		self.add_query_param('ConnectionStringPrefix', ConnectionStringPrefix)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_CurrentConnectionString(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_CurrentConnectionString(self): # String
 		return self.get_query_params().get('CurrentConnectionString')
 
-	def set_CurrentConnectionString(self,CurrentConnectionString):
-		self.add_query_param('CurrentConnectionString',CurrentConnectionString)
-
-	def get_Port(self):
+	def set_CurrentConnectionString(self, CurrentConnectionString):  # String
+		self.add_query_param('CurrentConnectionString', CurrentConnectionString)
+	def get_Port(self): # String
 		return self.get_query_params().get('Port')
 
-	def set_Port(self,Port):
-		self.add_query_param('Port',Port)
\ No newline at end of file
+	def set_Port(self, Port):  # String
+		self.add_query_param('Port', Port)
