@@ -46,6 +46,11 @@ class ModifySecurityIpsRequest(RpcRequest):
 
 	def set_DBInstanceId(self, DBInstanceId):  # String
 		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_ModifyMode(self): # String
+		return self.get_query_params().get('ModifyMode')
+
+	def set_ModifyMode(self, ModifyMode):  # String
+		self.add_query_param('ModifyMode', ModifyMode)
 	def get_SecurityIPList(self): # String
 		return self.get_query_params().get('SecurityIPList')
 
